==> bibledit-0.9.tar.gz: bibledit-0.9/src/backup.h <==
/*
** Copyright (C) 2003-2005 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_BACKUP_H
#define INCLUDED_BACKUP_H

#include "libraries.h"


class Backup
{
public:
  Backup (int dummy);
  ~Backup ();
  void clear ();
/*
  void load (const string & directory, vector <string>& filenames);
  unsigned int size ();
  string get_full_name (const string & friendly_name);
  string get_friendly_name (unsigned int index);
  void sort_out_old_backups ();
private:
  string backup_directory;
  vector < string > backups;
  string convert_weekday (Gxlib::Date::Weekday weekday);
  Gxlib::Date today;
  Gxlib::Date::Year extract_year (const string & filename);
  Gxlib::Date::Month extract_month (const string & filename);
  Gxlib::Date::Day extract_day (const string & filename);
  */
};


#endif

==> bibledit-1.4.tar.gz: bibledit-1.4/src/backup.h <==
/*
** Copyright (C) 2003-2005 The Free Software Foundation.
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#ifndef INCLUDED_BACKUP_H
#define INCLUDED_BACKUP_H

#include "libraries.h"


class Backup
{
public:
  Backup (int dummy);
  ~Backup ();
  void clear ();
/*
  void load (const ustring & directory, vector <ustring>& filenames);
  unsigned int size ();
  ustring get_full_name (const ustring & friendly_name);
  ustring get_friendly_name (unsigned int index);
  void sort_out_old_backups ();
private:
  ustring backup_directory;
  vector < ustring > backups;
  ustring convert_weekday (Gxlib::Date::Weekday weekday);
  Gxlib::Date today;
  Gxlib::Date::Year extract_year (const ustring & filename);
  Gxlib::Date::Month extract_month (const ustring & filename);
  Gxlib::Date::Day extract_day (const ustring & filename);
  */
};


#endif
